<?php namespace ProcessWire;

class FlexFieldsDemo extends RepeaterFlexItem {
	public static function getModuleInfo() {
		return array(
			'title' => __('Flex Fields Demo', __FILE__), // Module Title
			'summary' => __('Example on how to specify input fields for an item.', __FILE__), // Module Summary
			'version' => 1,
			'renderer' => 'ContentRenderer',
			'head' => '{flex_label} [• {FancyImages.count} Images, Roles: {roles*name}, {TextOnly}, {header_type}/{ColorOption.title} ]',
			'icon' => 'fa fa-thumbs-o-up',
			);
	}
	public static function getFields() { return [
		// Refer to an existing field, use it as is.
// Avoid using the standard email field on a productive system
// since it slows down repeater enumeration significantly (the field.
// is retrieved for each repeater along with some hooked system stuff).
// This is only used as a very simple example!
//		'email' => [ ],

		// Refer to an existing field, but change some attributes
		// Please note that the regular roles field is marked permanent so
		// that it can not be removed from the repeater template afterwards.
		'roles' => [
			'context' => [
				'label' => __("Select allowed roles"),
				'description' => __("Select roles allowed to use this field, others will see an error message!"),
				'columnWidth' => 25,
				],
		],

		// Refer to a real field, create if it does not exist
		'header_type' => [
			'context' => [
				'columnWidth' => 25,
				],
			'setup' => [	// may be used to create fields automatically
				'type' => 'FieldtypeOptions',
				'label' => __('Paragraph Type'),
				'inputfieldClass' => 'InputfieldSelect',
				'required' => 1,
				'defaultValue' => 'p',
				'initValue' => '',
				'columnWidth' => 25,
				'options' => [
					1 => 'p|'.__('Standard'),
					2 => 'h1|'.__('Header1'),
					3 => 'h2|'.__('Header2'),
					4 => 'h3|'.__('Header3'),
					5 => 'h4|'.__('Header4'),
					6 => 'h5|'.__('Header5'),
					],
				],
			],

		// Define a textfield for markup using field Prototypes in RepeaterFlexItem, specify label only
		'@TextOnly' => [
			'fieldtype' => 'Text', 
			'hint' => __('Select a plain Textfield without markup'),
			'context' => [
				'label' => __('Info for restricted roles'),
				'required' => 1,
				'columnWidth' => 25,
				],
			],

		// Define an option field using field Prototypes in RepeaterFlexItem
		'@ColorOption' => RepeaterFlexItem::Options([
				'columnWidth' => 25,
				'label' => __("Message color"),
				'inputfieldClass' => 'InputfieldSelect',
				'required' => 1,
				'defaultValue' => '1',
				'columnWidth' => 25,
				'options' => [
					1 => [ 'color' => '#F00', 'title' => __('red') ],
					2 => [ 'color' => '#0F0', 'title' => __('green') ],
					3 => [ 'color' => '#00F', 'title' => __('blue') ],
					4 => [ 'color' => '#000', 'title' => __('black') ],
					],
			]),

		// Define a virtual field using field prototype from RepeaterFlexItem and specify only the title.
		'@FancyImages' => RepeaterFlexItem::Images(__('Upload only nice pictures!')),
		];
	}

	public function render(Page $pg) {
		$user = wire('user');			// Obtain current user
		$bOk = false;
		foreach($pg->roles as $role)	// Enumerate selected roles...
			{
			if($user->hasRole($role))	// ...and check if the current user has at least one of them.
				$bOk = true;
			}
		if(!$bOk)	// User does not have any of the allowed roles, output the configured warning.
			{
			$Tag = $this->ctx->getTag($pg->header_type->value);
			$Tag->addAttributes([ 'style' => "color:{$pg->ColorOption->color};" ]);
			return($Tag->getOpenTag() . $pg->TextOnly . $Tag->getCloseTag());
			}
			
		// User has at least one allowed role, output images as thumbnails
		$out = '<div>';
		foreach($pg->FancyImages as $img)
			$out .= '<img src="'.$img->size(300,300)->url.'"/>';
		$out .= '</div>';
		return($out);
		}
}
